[![PyPI](https://img.shields.io/pypi/v/pybet.svg?style=for-the-badge)](https://pypi.org/project/pybet/)
![GitHub last commit (master)](https://img.shields.io/github/last-commit/peaky76/pybet/master)
![GitHub repo size](https://img.shields.io/github/repo-size/peaky76/pybet)
[![Documentation Status](https://readthedocs.org/projects/pybet/badge/?version=latest)](https://pybet.readthedocs.io/en/latest/?badge=latest)

# pybet

pybet is a library of betting utilities to assist with calculation of bets, stakes and markets

## Installation

`pip install pybet`

or

`poetry add pybet`
